@@ -1,15 +1,15 @@
-krugman.conc2 <-
-function (e_ij, e_uj) {
+krugman.conc2 <- function (e_ij, e_uj) {
   
-  compind <- length(e_uj)
-  
-  regions <- nrow(e_uj)
+
+  compind <- ncol(as.matrix(e_uj))
+
+  regions <- nrow(as.matrix(e_uj))
 
   s_ij <- vector()
   s_uj <- vector()
   
   e_j <- sum (e_ij)
-  
+
   i <- 0
   
   for (i in 1:regions) {
@@ -21,12 +21,12 @@ function (e_ij, e_uj) {
   
   s_uj <- matrix(nrow = compind, ncol = regions)
   e_l <- vector()
-
+  
   for (j in 1:compind)
   {
     
     for (i in 1:regions) {
-    
+      
       e_l[j] <- sum (e_uj[,j]) 
       s_uj[j,i] <- e_uj[i,j]/e_l[j]
 
@@ -42,4 +42,4 @@ function (e_ij, e_uj) {
   
   return(K_i)
   
-}
+}
\ No newline at end of file
