@@ -1,21 +1,33 @@
-var2 <-
-function (x, is.sample = TRUE, weighting = NULL, wmean = FALSE, na.rm = TRUE)
+var2 <- function (x, is.sample = TRUE, weighting = NULL, wmean = FALSE, na.rm = TRUE)
 {
-
   
   if (!is.null(weighting))
   {
+    
     if (length(x) != length(weighting))
     {
       stop("Frequency and weighting differ in length", call. = FALSE)
     }
   }
- 
-  if (na.rm == TRUE)
-  {
-    x <- x[!is.na(x)]
+  
+  if (na.rm == TRUE) {
+    
+    if (!is.null(weighting)) {
+      x_w <- as.matrix(cbind(x, weighting))
+      
+      x_w <- x_w[complete.cases(x_w),]
+      
+      x <- x_w[,1]
+      weighting <- x_w[,2]
+    }
+    
+    else {
+      x <- x[!is.na(x)]
+    }
+    
   }
   
+  
   if (is.sample == TRUE)
   {
     n <- length(x)-1
@@ -46,4 +58,4 @@ function (x, is.sample = TRUE, weighting = NULL, wmean = FALSE, na.rm = TRUE)
   }
   
   return(var_x)
-}
+}
\ No newline at end of file
